Crate sqlite_wasm_rs

Crate sqlite_wasm_rs 

Crates.io

wasm32-unknown-unknown bindings to the libsqlite3 library.

Usage

[dependencies]
sqlite-wasm-rs = "0.5"
[dependencies]
# Encryption is supported by SQLite3MultipleCiphers
# See <https://utelle.github.io/SQLite3MultipleCiphers>
sqlite-wasm-rs = { version = "0.5", features = ["sqlite3mc"] }
use sqlite_wasm_rs as ffi;

fn open_db() {
    // open with memory vfs
    let mut db = std::ptr::null_mut();
    let ret = unsafe {
        ffi::sqlite3_open_v2(
            c"mem.db".as_ptr().cast(),
            &mut db as *mut _,
            ffi::SQLITE_OPEN_READWRITE | ffi::SQLITE_OPEN_CREATE,
            std::ptr::null()
        )
    };
    assert_eq!(ffi::SQLITE_OK, ret);
}

About VFS

[dependencies]
# It requires sqlite-wasm-rs 0.5.2 or higher to be used,
# for version 0.5.1, use version 0.1 instead.
sqlite-wasm-vfs = "0.2"

The following vfs have been implemented:

  • memory: as the default vfs, no additional conditions are required, store the database in memory.
  • sahpool: ported from sqlite-wasm, store the database in opfs.
  • relaxed-idb: store the database in blocks in indexed db.

VFS Comparison

MemoryVFSSyncAccessHandlePoolVFSRelaxedIdbVFS
StorageRAMOPFSIndexedDB
ContextsAllDedicated WorkerAll
Multiple connections:x::x::x:
Full durability:x:
Relaxed durability:x::x:
Multi-database transactions
No COOP/COEP requirements

How to implement a VFS

Here is an example showing how to use sqlite-wasm-rs to implement a simple in-memory VFS, see implement-a-vfs example.

About multithreading

This library is not thread-safe:

Use prebuild libsqlite3.a

We provide the ability to use prebuild libsqlite3.a, cargo provides a links field that can be used to specify which library to link to. With the help of overriding build scripts, you can overriding its configuration in your crate and link sqlite to your prebuild libsqlite3.a.

More see use-prebuild-lib example.

Minimum supported Rust version (MSRV)

The minimal officially supported rustc version is 1.81.0.

Extensions

ExtensionAbout
sqlite-vecA vector search SQLite extension that runs anywhere!

Contributions are welcome!

  • diesel: A safe, extensible ORM and Query Builder for Rust.
  • rusqlite: Ergonomic bindings to SQLite for Rust.
  • sqlite-wasm: SQLite Wasm conveniently wrapped as an ES Module.
  • sqlite-web-rs: A SQLite WebAssembly backend for Diesel.
  • wa-sqlite: WebAssembly SQLite with support for browser storage extensions.
  • SQLite3MultipleCiphers: SQLite3 encryption extension with support for multiple ciphers.

Modules

utils
Low-level utilities, traits, and macros for implementing custom SQLite Virtual File Systems (VFS)

Macros

bail
A macro to return a specific SQLite error code if a condition is true.
check_option
A macro to safely unwrap an Option<T>, returning a SQLite error code on None.
check_result
A macro to safely unwrap a Result<T, E>, returning a SQLite error code on Err.

Structs

Error
Raw C-style bindings to the underlying libsqlite3 library.
Fts5Context
Raw C-style bindings to the underlying libsqlite3 library.
Fts5ExtensionApi
Raw C-style bindings to the underlying libsqlite3 library.
Fts5PhraseIter
Raw C-style bindings to the underlying libsqlite3 library.
Fts5Tokenizer
Raw C-style bindings to the underlying libsqlite3 library.
MemVfsUtil
In-memory VFS implementation. MemVfs management tool.
WasmOsCallback
Wasm platform implementation
fts5_api
Raw C-style bindings to the underlying libsqlite3 library.
fts5_tokenizer
Raw C-style bindings to the underlying libsqlite3 library.
fts5_tokenizer_v2
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_api_routines
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_backup
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_blob
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_changegroup
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_changeset_iter
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_context
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_file
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_index_constraint
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_index_constraint_usage
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_index_info
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_index_orderby
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_io_methods
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_mem_methods
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_module
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_mutex
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_mutex_methods
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_pcache
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_pcache_methods
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_pcache_methods2
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_pcache_page
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_rebaser
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_rtree_geometry
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_rtree_query_info
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_session
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_snapshot
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_stmt
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_str
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_value
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_vfs
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_vtab
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_vtab_cursor
Raw C-style bindings to the underlying libsqlite3 library.

Enums

ErrorCode
Raw C-style bindings to the underlying libsqlite3 library. Error Codes
MemVfsError
In-memory VFS implementation.

Constants

CARRAY_BLOB
Raw C-style bindings to the underlying libsqlite3 library.
CARRAY_DOUBLE
Raw C-style bindings to the underlying libsqlite3 library.
CARRAY_INT32
Raw C-style bindings to the underlying libsqlite3 library.
CARRAY_INT64
Raw C-style bindings to the underlying libsqlite3 library.
CARRAY_TEXT
Raw C-style bindings to the underlying libsqlite3 library.
FTS5_TOKENIZE_AUX
Raw C-style bindings to the underlying libsqlite3 library.
FTS5_TOKENIZE_DOCUMENT
Raw C-style bindings to the underlying libsqlite3 library.
FTS5_TOKENIZE_PREFIX
Raw C-style bindings to the underlying libsqlite3 library.
FTS5_TOKENIZE_QUERY
Raw C-style bindings to the underlying libsqlite3 library.
FTS5_TOKEN_COLOCATED
Raw C-style bindings to the underlying libsqlite3 library.
FULLY_WITHIN
Raw C-style bindings to the underlying libsqlite3 library.
NOT_WITHIN
Raw C-style bindings to the underlying libsqlite3 library.
PARTLY_WITHIN
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE3_TEXT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ABORT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ABORT_ROLLBACK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ACCESS_EXISTS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ACCESS_READ
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ACCESS_READWRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ALTER_TABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ANALYZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ANY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ATTACH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_AUTH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_AUTH_USER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_BLOB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_BUSY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_BUSY_RECOVERY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_BUSY_SNAPSHOT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_BUSY_TIMEOUT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CANTOPEN
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CANTOPEN_CONVPATH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CANTOPEN_DIRTYWAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CANTOPEN_FULLPATH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CANTOPEN_ISDIR
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CANTOPEN_NOTEMPDIR
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CANTOPEN_SYMLINK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CARRAY_BLOB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CARRAY_DOUBLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CARRAY_INT32
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CARRAY_INT64
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CARRAY_TEXT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGEGROUP_CONFIG_PATCHSET
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESETAPPLY_FKNOACTION
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESETAPPLY_IGNORENOOP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESETAPPLY_INVERT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESETAPPLY_NOSAVEPOINT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESETSTART_INVERT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESET_ABORT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESET_CONFLICT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESET_CONSTRAINT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESET_DATA
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESET_FOREIGN_KEY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESET_NOTFOUND
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESET_OMIT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHANGESET_REPLACE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHECKPOINT_FULL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHECKPOINT_NOOP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHECKPOINT_PASSIVE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHECKPOINT_RESTART
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CHECKPOINT_TRUNCATE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_COVERING_INDEX_SCAN
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_GETMALLOC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_GETMUTEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_GETPCACHE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_GETPCACHE2
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_HEAP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_LOG
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_LOOKASIDE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_MALLOC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_MEMDB_MAXSIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_MEMSTATUS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_MMAP_SIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_MULTITHREAD
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_MUTEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_PAGECACHE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_PCACHE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_PCACHE2
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_PCACHE_HDRSZ
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_PMASZ
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_ROWID_IN_VIEW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_SCRATCH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_SERIALIZED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_SINGLETHREAD
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_SMALL_MALLOC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_SORTERREF_SIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_SQLLOG
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_STMTJRNL_SPILL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_URI
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONFIG_WIN32_HEAPSIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_CHECK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_COMMITHOOK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_DATATYPE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_FOREIGNKEY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_FUNCTION
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_NOTNULL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_PINNED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_PRIMARYKEY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_ROWID
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_TRIGGER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_UNIQUE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CONSTRAINT_VTAB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_COPY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CORRUPT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CORRUPT_INDEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CORRUPT_SEQUENCE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CORRUPT_VTAB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CREATE_INDEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CREATE_TABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CREATE_TEMP_INDEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CREATE_TEMP_TABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CREATE_TEMP_TRIGGER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CREATE_TEMP_VIEW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CREATE_TRIGGER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CREATE_VIEW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_CREATE_VTABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_DEFENSIVE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_DQS_DDL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_DQS_DML
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_ENABLE_ATTACH_CREATE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_ENABLE_ATTACH_WRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_ENABLE_COMMENTS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_ENABLE_FKEY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_ENABLE_FTS3_TOKENIZER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_ENABLE_LOAD_EXTENSION
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_ENABLE_QPSG
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_ENABLE_TRIGGER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_ENABLE_VIEW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_FP_DIGITS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_LEGACY_ALTER_TABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_LEGACY_FILE_FORMAT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_LOOKASIDE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_MAINDBNAME
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_MAX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_NO_CKPT_ON_CLOSE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_RESET_DATABASE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_REVERSE_SCANORDER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_STMT_SCANSTATUS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_TRIGGER_EQP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_TRUSTED_SCHEMA
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBCONFIG_WRITABLE_SCHEMA
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_CACHE_HIT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_CACHE_MISS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_CACHE_SPILL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_CACHE_USED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_CACHE_USED_SHARED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_CACHE_WRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_DEFERRED_FKS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_LOOKASIDE_HIT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_LOOKASIDE_MISS_FULL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_LOOKASIDE_MISS_SIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_LOOKASIDE_USED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_MAX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_SCHEMA_USED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_STMT_USED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DBSTATUS_TEMPBUF_SPILL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DELETE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DENY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DESERIALIZE_FREEONCLOSE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DESERIALIZE_READONLY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DESERIALIZE_RESIZEABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DETACH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DETERMINISTIC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DIRECTONLY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DONE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DROP_INDEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DROP_TABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DROP_TEMP_INDEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DROP_TEMP_TABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DROP_TEMP_TRIGGER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DROP_TEMP_VIEW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DROP_TRIGGER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DROP_VIEW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_DROP_VTABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_EMPTY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ERROR
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ERROR_KEY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ERROR_MISSING_COLLSEQ
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ERROR_RESERVESIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ERROR_RETRY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ERROR_SNAPSHOT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ERROR_UNABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FAIL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_BEGIN_ATOMIC_WRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_BLOCK_ON_CONNECT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_BUSYHANDLER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_CHUNK_SIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_CKPT_DONE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_CKPT_START
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_CKSM_FILE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_COMMIT_ATOMIC_WRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_COMMIT_PHASETWO
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_DATA_VERSION
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_EXTERNAL_READER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_FILESTAT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_FILE_POINTER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_GET_LOCKPROXYFILE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_HAS_MOVED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_JOURNAL_POINTER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_LAST_ERRNO
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_LOCKSTATE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_LOCK_TIMEOUT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_MMAP_SIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_NULL_IO
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_OVERWRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_PDB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_PERSIST_WAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_POWERSAFE_OVERWRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_PRAGMA
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_RBU
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_RESERVE_BYTES
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_RESET_CACHE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_ROLLBACK_ATOMIC_WRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_SET_LOCKPROXYFILE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_SIZE_HINT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_SIZE_LIMIT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_SYNC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_SYNC_OMITTED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_TEMPFILENAME
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_TRACE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_VFSNAME
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_VFS_POINTER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_WAL_BLOCK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_WIN32_AV_RETRY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_WIN32_GET_HANDLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_WIN32_SET_HANDLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FCNTL_ZIPVFS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FLOAT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FORMAT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FULL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_FUNCTION
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_GET_LOCKPROXYFILE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IGNORE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_EQ
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_FUNCTION
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_GE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_GLOB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_GT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_IS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_ISNOT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_ISNOTNULL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_ISNULL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_LE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_LIKE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_LIMIT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_LT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_MATCH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_NE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_OFFSET
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_CONSTRAINT_REGEXP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_SCAN_HEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INDEX_SCAN_UNIQUE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INNOCUOUS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INSERT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INTEGER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INTERNAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_INTERRUPT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_ATOMIC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_ATOMIC1K
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_ATOMIC2K
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_ATOMIC4K
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_ATOMIC8K
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_ATOMIC16K
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_ATOMIC32K
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_ATOMIC64K
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_ATOMIC512
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_BATCH_ATOMIC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_IMMUTABLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_POWERSAFE_OVERWRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_SAFE_APPEND
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_SEQUENTIAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_SUBPAGE_READ
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOCAP_UNDELETABLE_WHEN_OPEN
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_ACCESS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_AUTH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_BADKEY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_BEGIN_ATOMIC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_BLOCKED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_CHECKRESERVEDLOCK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_CLOSE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_CODEC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_COMMIT_ATOMIC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_CONVPATH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_CORRUPTFS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_DATA
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_DELETE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_DELETE_NOENT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_DIR_CLOSE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_DIR_FSYNC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_FSTAT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_FSYNC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_GETTEMPPATH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_IN_PAGE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_LOCK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_MMAP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_NOMEM
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_RDLOCK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_READ
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_ROLLBACK_ATOMIC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_SEEK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_SHMLOCK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_SHMMAP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_SHMOPEN
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_SHMSIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_SHORT_READ
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_TRUNCATE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_UNLOCK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_VNODE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_IOERR_WRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LAST_ERRNO
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_ATTACHED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_COLUMN
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_COMPOUND_SELECT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_EXPR_DEPTH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_FUNCTION_ARG
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_LENGTH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_LIKE_PATTERN_LENGTH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_PARSER_DEPTH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_SQL_LENGTH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_TRIGGER_DEPTH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_VARIABLE_NUMBER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_VDBE_OP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LIMIT_WORKER_THREADS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LOCKED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LOCKED_SHAREDCACHE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LOCKED_VTAB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LOCK_EXCLUSIVE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LOCK_NONE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LOCK_PENDING
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LOCK_RESERVED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_LOCK_SHARED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MISMATCH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MISUSE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_FAST
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_RECURSIVE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_APP1
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_APP2
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_APP3
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_LRU
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_LRU2
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_MAIN
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_MASTER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_MEM
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_MEM2
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_OPEN
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_PMEM
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_PRNG
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_VFS1
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_VFS2
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_MUTEX_STATIC_VFS3
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_NOLFS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_NOMEM
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_NOTADB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_NOTFOUND
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_NOTICE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_NOTICE_RBU
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_NOTICE_RECOVER_ROLLBACK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_NOTICE_RECOVER_WAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_NULL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OK_LOAD_PERMANENTLY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OK_SYMLINK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_AUTOPROXY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_CREATE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_DELETEONCLOSE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_EXCLUSIVE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_EXRESCODE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_FULLMUTEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_MAIN_DB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_MAIN_JOURNAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_MASTER_JOURNAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_MEMORY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_NOFOLLOW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_NOMUTEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_PRIVATECACHE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_READONLY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_READWRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_SHAREDCACHE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_SUBJOURNAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_SUPER_JOURNAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_TEMP_DB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_TEMP_JOURNAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_TRANSIENT_DB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_URI
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_OPEN_WAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_PERM
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_PRAGMA
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_PREPARE_DONT_LOG
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_PREPARE_FROM_DDL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_PREPARE_NORMALIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_PREPARE_NO_VTAB
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_PREPARE_PERSISTENT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_PROTOCOL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_RANGE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_READ
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_READONLY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_READONLY_CANTINIT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_READONLY_CANTLOCK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_READONLY_DBMOVED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_READONLY_DIRECTORY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_READONLY_RECOVERY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_READONLY_ROLLBACK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_RECURSIVE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_REINDEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_REPLACE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_RESULT_SUBTYPE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ROLLBACK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_ROW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SAVEPOINT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCANSTAT_COMPLEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCANSTAT_EST
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCANSTAT_EXPLAIN
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCANSTAT_NAME
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCANSTAT_NCYCLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCANSTAT_NLOOP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCANSTAT_NVISIT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCANSTAT_PARENTID
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCANSTAT_SELECTID
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCHEMA
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCM_BRANCH
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCM_DATETIME
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SCM_TAGS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SELECT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SELFORDER1
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SERIALIZE_NOCOPY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SESSION_CONFIG_STRMSIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SESSION_OBJCONFIG_ROWID
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SESSION_OBJCONFIG_SIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SETLK_BLOCK_ON_CONNECT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SET_LOCKPROXYFILE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SHM_EXCLUSIVE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SHM_LOCK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SHM_NLOCK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SHM_SHARED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SHM_UNLOCK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SOURCE_ID
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STATUS_MALLOC_COUNT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STATUS_MALLOC_SIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STATUS_MEMORY_USED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STATUS_PAGECACHE_OVERFLOW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STATUS_PAGECACHE_SIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STATUS_PAGECACHE_USED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STATUS_PARSER_STACK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STATUS_SCRATCH_OVERFLOW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STATUS_SCRATCH_SIZE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STATUS_SCRATCH_USED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STMTSTATUS_AUTOINDEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STMTSTATUS_FILTER_HIT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STMTSTATUS_FILTER_MISS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STMTSTATUS_FULLSCAN_STEP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STMTSTATUS_MEMUSED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STMTSTATUS_REPREPARE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STMTSTATUS_RUN
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STMTSTATUS_SORT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_STMTSTATUS_VM_STEP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SUBTYPE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SYNC_DATAONLY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SYNC_FULL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_SYNC_NORMAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_ALWAYS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_ASSERT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_ATOF
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_BENIGN_MALLOC_HOOKS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_BITVEC_TEST
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_BYTEORDER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_EXPLAIN_STMT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_EXTRA_SCHEMA_CHECKS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_FAULT_INSTALL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_FIRST
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_FK_NO_ACTION
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_GETOPT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_IMPOSTER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_INTERNAL_FUNCTIONS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_ISINIT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_ISKEYWORD
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_JSON_SELFCHECK
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_LAST
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_LOCALTIME_FAULT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_LOGEST
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_NEVER_CORRUPT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_ONCE_RESET_THRESHOLD
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_OPTIMIZATIONS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_PARSER_COVERAGE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_PENDING_BYTE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_PRNG_RESET
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_PRNG_RESTORE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_PRNG_SAVE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_PRNG_SEED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_RESERVE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_RESULT_INTREAL
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_SCRATCHMALLOC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_SEEK_COUNT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_SORTER_MMAP
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_TRACEFLAGS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_TUNE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_USELONGDOUBLE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TESTCTRL_VDBE_COVERAGE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TEXT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TOOBIG
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TRACE_CLOSE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TRACE_PROFILE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TRACE_ROW
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TRACE_STMT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TRANSACTION
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TXN_NONE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TXN_READ
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TXN_WRITE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_UPDATE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_UTF8
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_UTF8_ZT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_UTF16
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_UTF16BE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_UTF16LE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_UTF16_ALIGNED
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_VERSION
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_VERSION_NUMBER
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_VTAB_CONSTRAINT_SUPPORT
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_VTAB_DIRECTONLY
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_VTAB_INNOCUOUS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_VTAB_USES_ALL_SCHEMAS
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_WARNING
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_WARNING_AUTOINDEX
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_WIN32_DATA_DIRECTORY_TYPE
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_WIN32_TEMP_DIRECTORY_TYPE
Raw C-style bindings to the underlying libsqlite3 library.

Statics

sqlite3_data_directory
sqlite3_temp_directory
sqlite3_version

Functions

SQLITE_STATIC
Raw C-style bindings to the underlying libsqlite3 library.
SQLITE_TRANSIENT
Raw C-style bindings to the underlying libsqlite3 library.
code_to_str
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_aggregate_context
sqlite3_auto_extension
sqlite3_autovacuum_pages
sqlite3_backup_finish
sqlite3_backup_init
sqlite3_backup_pagecount
sqlite3_backup_remaining
sqlite3_backup_step
sqlite3_bind_blob
sqlite3_bind_blob64
sqlite3_bind_double
sqlite3_bind_int
sqlite3_bind_int64
sqlite3_bind_null
sqlite3_bind_parameter_count
sqlite3_bind_parameter_index
sqlite3_bind_parameter_name
sqlite3_bind_pointer
sqlite3_bind_text
sqlite3_bind_text64
sqlite3_bind_value
sqlite3_bind_zeroblob
sqlite3_bind_zeroblob64
sqlite3_blob_bytes
sqlite3_blob_close
sqlite3_blob_open
sqlite3_blob_read
sqlite3_blob_reopen
sqlite3_blob_write
sqlite3_busy_handler
sqlite3_busy_timeout
sqlite3_cancel_auto_extension
sqlite3_carray_bind
sqlite3_carray_bind_v2
sqlite3_changes
sqlite3_changes64
sqlite3_clear_bindings
sqlite3_close
sqlite3_collation_needed
sqlite3_column_blob
sqlite3_column_bytes
sqlite3_column_count
sqlite3_column_database_name
sqlite3_column_decltype
sqlite3_column_double
sqlite3_column_int
sqlite3_column_int64
sqlite3_column_name
sqlite3_column_origin_name
sqlite3_column_table_name
sqlite3_column_text
sqlite3_column_type
sqlite3_column_value
sqlite3_commit_hook
sqlite3_compileoption_get
sqlite3_compileoption_used
sqlite3_complete
sqlite3_config
sqlite3_context_db_handle
sqlite3_create_collation_v2
sqlite3_create_filename
sqlite3_create_function_v2
sqlite3_create_module_v2
sqlite3_create_window_function
sqlite3_data_count
sqlite3_database_file_object
sqlite3_db_cacheflush
sqlite3_db_config
sqlite3_db_filename
sqlite3_db_handle
sqlite3_db_mutex
sqlite3_db_name
sqlite3_db_readonly
sqlite3_db_release_memory
sqlite3_db_status
sqlite3_db_status64
sqlite3_declare_vtab
sqlite3_deserialize
sqlite3_drop_modules
sqlite3_enable_load_extension
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_enable_shared_cache
sqlite3_errcode
sqlite3_errmsg
sqlite3_error_offset
sqlite3_errstr
sqlite3_exec
sqlite3_expanded_sql
sqlite3_extended_errcode
sqlite3_extended_result_codes
sqlite3_file_control
sqlite3_filename_database
sqlite3_filename_journal
sqlite3_filename_wal
sqlite3_finalize
sqlite3_free
sqlite3_free_filename
sqlite3_free_table
sqlite3_get_autocommit
sqlite3_get_auxdata
sqlite3_get_clientdata
sqlite3_get_table
sqlite3_hard_heap_limit64
sqlite3_initialize
sqlite3_interrupt
sqlite3_is_interrupted
sqlite3_keyword_check
sqlite3_keyword_count
sqlite3_keyword_name
sqlite3_last_insert_rowid
sqlite3_libversion
sqlite3_libversion_number
sqlite3_limit
sqlite3_load_extension
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_log
sqlite3_malloc
sqlite3_malloc64
sqlite3_memory_highwater
sqlite3_memory_used
sqlite3_mprintf
sqlite3_msize
sqlite3_mutex_alloc
sqlite3_mutex_enter
sqlite3_mutex_free
sqlite3_mutex_held
sqlite3_mutex_leave
sqlite3_mutex_notheld
sqlite3_mutex_try
sqlite3_next_stmt
sqlite3_open
sqlite3_open_v2
sqlite3_os_end
sqlite3_os_init
sqlite3_overload_function
sqlite3_prepare_v2
sqlite3_prepare_v3
sqlite3_preupdate_blobwrite
sqlite3_preupdate_count
sqlite3_preupdate_depth
sqlite3_preupdate_hook
sqlite3_preupdate_new
sqlite3_preupdate_old
sqlite3_progress_handler
sqlite3_randomness
sqlite3_realloc
sqlite3_realloc64
sqlite3_release_memory
sqlite3_reset
sqlite3_reset_auto_extension
sqlite3_result_blob
sqlite3_result_blob64
sqlite3_result_double
sqlite3_result_error
sqlite3_result_error_code
sqlite3_result_error_nomem
sqlite3_result_error_toobig
sqlite3_result_int
sqlite3_result_int64
sqlite3_result_null
sqlite3_result_pointer
sqlite3_result_subtype
sqlite3_result_text
sqlite3_result_text64
sqlite3_result_value
sqlite3_result_zeroblob
sqlite3_result_zeroblob64
sqlite3_rollback_hook
sqlite3_rtree_geometry_callback
sqlite3_rtree_query_callback
sqlite3_serialize
sqlite3_set_authorizer
sqlite3_set_auxdata
sqlite3_set_clientdata
sqlite3_set_errmsg
sqlite3_set_last_insert_rowid
sqlite3_setlk_timeout
sqlite3_shutdown
sqlite3_sleep
sqlite3_snapshot_cmp
sqlite3_snapshot_free
sqlite3_snapshot_get
sqlite3_snapshot_open
sqlite3_snapshot_recover
sqlite3_snprintf
sqlite3_soft_heap_limit
sqlite3_soft_heap_limit64
sqlite3_sourceid
sqlite3_sql
sqlite3_status
sqlite3_status64
sqlite3_step
sqlite3_stmt_busy
sqlite3_stmt_explain
sqlite3_stmt_isexplain
sqlite3_stmt_readonly
sqlite3_stmt_scanstatus
sqlite3_stmt_scanstatus_reset
sqlite3_stmt_scanstatus_v2
sqlite3_stmt_status
sqlite3_str_append
sqlite3_str_appendall
sqlite3_str_appendchar
sqlite3_str_appendf
sqlite3_str_errcode
sqlite3_str_finish
sqlite3_str_free
sqlite3_str_length
sqlite3_str_new
sqlite3_str_reset
sqlite3_str_truncate
sqlite3_str_value
sqlite3_strglob
sqlite3_stricmp
sqlite3_strlike
sqlite3_strnicmp
sqlite3_system_errno
sqlite3_table_column_metadata
sqlite3_test_control
sqlite3_threadsafe
sqlite3_total_changes
sqlite3_total_changes64
sqlite3_trace_v2
sqlite3_txn_state
sqlite3_unlock_notify
sqlite3_update_hook
sqlite3_uri_boolean
sqlite3_uri_int64
sqlite3_uri_key
sqlite3_uri_parameter
sqlite3_user_data
sqlite3_value_blob
sqlite3_value_bytes
sqlite3_value_double
sqlite3_value_dup
sqlite3_value_encoding
sqlite3_value_free
sqlite3_value_frombind
sqlite3_value_int
sqlite3_value_int64
sqlite3_value_nochange
sqlite3_value_numeric_type
sqlite3_value_pointer
sqlite3_value_subtype
sqlite3_value_text
sqlite3_value_type
sqlite3_vfs_find
sqlite3_vfs_register
sqlite3_vfs_unregister
sqlite3_vtab_collation
sqlite3_vtab_config
sqlite3_vtab_distinct
sqlite3_vtab_in
sqlite3_vtab_in_first
sqlite3_vtab_in_next
sqlite3_vtab_nochange
sqlite3_vtab_on_conflict
sqlite3_vtab_rhs_value
sqlite3_wal_autocheckpoint
sqlite3_wal_checkpoint
sqlite3_wal_checkpoint_v2
sqlite3_wal_hook
sqlite3_win32_set_directory
sqlite3_win32_set_directory8
sqlite3changegroup_add
sqlite3changegroup_add_change
sqlite3changegroup_add_strm
sqlite3changegroup_change_begin
sqlite3changegroup_change_blob
sqlite3changegroup_change_double
sqlite3changegroup_change_finish
sqlite3changegroup_change_int64
sqlite3changegroup_change_null
sqlite3changegroup_change_text
sqlite3changegroup_config
sqlite3changegroup_delete
sqlite3changegroup_new
sqlite3changegroup_output
sqlite3changegroup_output_strm
sqlite3changegroup_schema
sqlite3changeset_apply
sqlite3changeset_apply_strm
sqlite3changeset_apply_v2
sqlite3changeset_apply_v3
sqlite3changeset_apply_v2_strm
sqlite3changeset_apply_v3_strm
sqlite3changeset_concat
sqlite3changeset_concat_strm
sqlite3changeset_conflict
sqlite3changeset_finalize
sqlite3changeset_fk_conflicts
sqlite3changeset_invert
sqlite3changeset_invert_strm
sqlite3changeset_new
sqlite3changeset_next
sqlite3changeset_old
sqlite3changeset_op
sqlite3changeset_pk
sqlite3changeset_start
sqlite3changeset_start_strm
sqlite3changeset_start_v2
sqlite3changeset_start_v2_strm
sqlite3rebaser_configure
sqlite3rebaser_create
sqlite3rebaser_delete
sqlite3rebaser_rebase
sqlite3rebaser_rebase_strm
sqlite3session_attach
sqlite3session_changeset
sqlite3session_changeset_size
sqlite3session_changeset_strm
sqlite3session_config
sqlite3session_create
sqlite3session_delete
sqlite3session_diff
sqlite3session_enable
sqlite3session_indirect
sqlite3session_isempty
sqlite3session_memory_used
sqlite3session_object_config
sqlite3session_patchset
sqlite3session_patchset_strm
sqlite3session_table_filter

Type Aliases

fts5_extension_function
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_callback
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_destructor_type
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_filename
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_int64
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_rtree_dbl
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_syscall_ptr
Raw C-style bindings to the underlying libsqlite3 library.
sqlite3_uint64
Raw C-style bindings to the underlying libsqlite3 library.
sqlite_int64
Raw C-style bindings to the underlying libsqlite3 library.
sqlite_uint64
Raw C-style bindings to the underlying libsqlite3 library.